// this sets the background color of the master UIView (when there are no windows/tab groups on it)
Titanium.UI.setBackgroundColor('#000');

var _default_latitude = 47.577;
var _default_longitude = -122.279;
var _default_delta = 0.05;

var _lastAction = '';

// Change this to production url
// var _mapPropertiesUrl = 'http://www.comient.com/Home/MapProperties'; 
var baseUrl = 'http://onioncom.w01.winhost.com/apps/Comient_Staging';
var _mapPropertiesUrl = 'http://onioncom.w01.winhost.com/apps/Comient_Staging/Home/MapProperties';

// create tab group
var _tabGroup = Titanium.UI.createTabGroup();

//
// Tab 1 - Map
//
var _winMap = Titanium.UI.createWindow({  
    backgroundColor:'#ccc',
	url: 'window_map.js',
    baseUrl: baseUrl
});
var _tabMap = Titanium.UI.createTab({  
    icon:'icon_map.png',
    title:'Map',
    window:_winMap
});

//
// Tab 2 - List
//
var _winList = Titanium.UI.createWindow({  
    title:'List',
    backgroundColor:'#ccc',
	url: 'window_list.js',
    baseUrl: baseUrl
});
var _tabList = Titanium.UI.createTab({  
    icon:'icon_list.png',
    title:'List',
    window:_winList
});

//
// Tab 3 - Location
//
var _winFind = Titanium.UI.createWindow({
	title: 'Find by City or ZIP Code',
	backgroundColor: '#ccc',
	url: 'window_location.js',
    baseUrl: baseUrl
});

var _tabFind = Titanium.UI.createTab({
	icon: 'icon_location.png',
	title: 'Location',
	window: _winFind
});

//
// Tab 4 - Near Me
//
var _winFindMe = Titanium.UI.createWindow({
	title: 'Near Me',
	backgroundColor: '#ccc',
	url: 'window_findme.js',
    baseUrl: baseUrl
});
var _tabFindMe = Titanium.UI.createTab({
	icon: 'icon_near-me.png',
	title: 'Near Me',
	window: _winFindMe
});

function setCurrentLocation(callback)
{
	Titanium.API.info('setCurrentLocation start');
    _winMap.title = 'locating';
	if (Titanium.Geolocation.locationServicesEnabled)
	{
		Titanium.Geolocation.accuracy = Titanium.Geolocation.ACCURACY_BEST;
		Titanium.Geolocation.distanceFilter = 1000;
		Titanium.Geolocation.getCurrentPosition(function(e)
		{
			if (e.error)
			{
				Titanium.API.info("app.setCurrentLocation - Could not get current location.");
				Titanium.App.fireEvent('location_changed',
				{
					latitude: _default_latitude,
					longitude: _default_longitude
				});
			}
			else
			{
				Titanium.API.info("app.setCurrentLocation - Position found: " + JSON.stringify(e));
				Titanium.App.fireEvent('location_changed',
				{
					title: 'Near You',
					latitude: e.coords.latitude,
					longitude: e.coords.longitude
				});
			}
			if (callback)
			{
				callback(e);
			}
		});
	}
    else
    {
        Titanium.API.info("app.setCurrentLocation - Location services disabled - setting default location");
		Titanium.App.fireEvent('location_changed',
		{
			latitude: _default_latitude,
			longitude: _default_longitude
		});
		if (callback)
		{
			callback();
		}
    }
}

//
// mapregion_changed is fired by the map view when a regionChanged
// event occurs on the Titanium.UI.MapView
//
// region change event listener
var _isPropertyInfoLoadPending = false;
var xhrGetPropertyInfo = Titanium.Network.createHTTPClient();
var _lastRequestTime = null;
xhrGetPropertyInfo.onload = function()
{
	Titanium.API.info("app.xhrGetPropertyInfo.onload - listing info load successful.");
    _isPropertyInfoLoadPending = false;
	
    var listings = JSON.parse(xhrGetPropertyInfo.responseText);
	if (!listings)
	{
	    var a = Titanium.UI.createAlertDialog({
	        title:'Network Error',
	        message:'There was an error retrieving listing data'
	    });
	    a.show();
		return;
	}

	_winList.listings = listings;
	_winMap.listings = listings;
	Titanium.App.fireEvent('listings_updated');
};
xhrGetPropertyInfo.onerror = function(e)
{
	if (e.error.contains("The request was cancelled"))
	{
		// This is a result of aborting a pending request.
		// It should not generate an error message.
	}
	else
	{
    	var a = Titanium.UI.createAlertDialog({
        	title:'Network Error',
        	message: e.error
		});
	    a.show();
	}

	Titanium.API.info("app.xhrGetPropertyInfo.onerror - ", e.error);
	Titanium.App.fireEvent('listings_updated', null);
};
xhrGetPropertyInfo.onreadystatechange = function(e)
{
	Titanium.API.info('app.xhrGetPropertyInfo.onreadystatechange: ' + xhrGetPropertyInfo.readyState);
	switch(xhrGetPropertyInfo.readyState)
	{
		
	}
};

function requestProperties(region)
{
	var d = new Date();
	var currentTime = d.getTime();
	Titanium.API.info('app - requestProperties at ' + d.getTime());
	if (_lastRequestTime && currentTime < _lastRequestTime + 450)
	{
		Titanium.API.info('app - consecutive update requests too close together, discarding earlier request.');
		return;
	}
    if (_isPropertyInfoLoadPending)
    {
        Titanium.API.info('location_changed - cancelling pending request in queue.');
		xhrGetPropertyInfo.abort();
    }
    _isPropertyInfoLoadPending = true;
    var requestString =
        _mapPropertiesUrl + 
        '?W=' + region.W +
        '&E=' + region.E +
        '&N=' + region.N +
        '&S=' + region.S;
    Titanium.API.info('request = ' + requestString);
	xhrGetPropertyInfo.open('GET', requestString); 	
    xhrGetPropertyInfo.send();
}

Titanium.App.addEventListener('mapregion_changed', function(region)
{
	var d = new Date();
	_lastRequestTime = d.getTime();
	Titanium.API.info('app - queuing requestProperties at: ' + d.getTime());
	setTimeout(function() { requestProperties(region); }, 500);
});

Titanium.App.addEventListener('go_to_my_location', function(e) {
	setCurrentLocation();
});

Titanium.App.addEventListener('location_changed', function(e) {
	_tabGroup.setActiveTab(0);
});


//
//  add tabs
//
_tabGroup.addTab(_tabMap);  
_tabGroup.addTab(_tabList);  
_tabGroup.addTab(_tabFind);
_tabGroup.addTab(_tabFindMe);

// Wait a bit before setting the current location so 
// that all windows have finished initializing.
// If we don't wait, event listeners for the application
// events haven't been attached yet.

setTimeout(function() {
	_tabGroup.setActiveTab(0);
	_tabGroup.open({transition:Titanium.UI.iPhone.AnimationStyle.FLIP_FROM_LEFT});
    Titanium.App.fireEvent('go_to_my_location');
}, 2000);

