//
// window_detail.js
//

var win = Titanium.UI.currentWindow;
win.backgroundColor = '#ddd';

var baseUrl;
if (win)
{
    baseUrl = win.baseUrl;
    Titanium.API.info("window_detail - baseUrl = " + baseUrl);
}
else
{
    Titanium.API.info("window_detail - baseUrl not set: window is empty");
}

var darkText = '#000';
var lightText = '#666';
var blueText = '#78a';
var borderColor = '#777';
var boxBackground = '#fff';

var smallFont1 = { fontSize: 12};
var smallFont2 = { fontSize: 12, fontWeight: 'bold' };
var bigFont = {fontSize: 13, fontWeight: 'bold'};

// dummy values
win.listing.ContactEMail = 'info@realtor.local';
win.listing.ContactName = 'Contact Name';

var truncatedTitle = win.listing.Title;
if (truncatedTitle.length > 40)
{
	truncatedTitle = truncatedTitle.substring(0,40) + "...";
}
	
var titleLabel = Titanium.UI.createLabel({
	text: truncatedTitle,
	color: '#000',
	fontSize: 13,
	height: 27,
	width: 300,
	left: 10,
	top: 0
});
win.add(titleLabel);

var detailsBox = Titanium.UI.createView({
	backgroundColor: boxBackground,
	borderRadius: 10,
	borderColor: borderColor,
	borderThickness: 1,
	width: 300,
	left: 10,
	top: 30,
	height: 195
});

var l1 = 10;
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: lightText, left: l1, top: 20, text: 'Space Available' }));
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: lightText, left: l1, top: 50, text: 'Rental Rate' }));
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: lightText, left: l1, top: 80, text: 'Property Type' }));
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: lightText, left: l1, top: 110, text: 'Building Class' }));
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: lightText, left: l1, top: 140, text: 'Smallest Divisible Size' }));

var l2 = 160;
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: darkText, left: l2, top: 20, text: win.listing.SquareFeet + 'SF'}));
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: darkText, left: l2, top: 50, text: '$' + win.listing.PricePerSqFt + '/SF/year' }));
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: darkText, left: l2, top: 80, text: win.listing.BuildingType }));
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: darkText, left: l2, top: 110, text: win.listing.BuildingClass }));
detailsBox.add(Titanium.UI.createLabel({font:smallFont1, color: darkText, left: l2, top: 140, text: win.listing.SmallestDivisibleSF + 'SF' }));

win.add(detailsBox);
function showLargeImage(imageUrl)
{
    var imageWindow = Titanium.UI.createWindow();
    var imageView = Titanium.UI.createImageView({
        url: imageUrl
    });
    var scrollView = Titanium.UI.createScrollView({
        contentHeight: 768,
        contentWidth: 1024,
        showVerticalScrollIndicator:true,
        showHorizontalScrollIndicator:true,
        backgroundColor: '#000',
        contentOffset: {x:512-160,y:384-200}        
    });
    imageWindow.add(scrollView);
    scrollView.add(imageView);
    Titanium.UI.currentTab.open(imageWindow, {animated:true});
}

function getThumbnailView(caption, listingId, imageKey)
{
	var view = Titanium.UI.createView({
		height: 80,
		width: 80,
		left: caption * 85 + 2,
		top: 2,
		borderWidth: 1,
		borderRadius: 3,
		textAlign: 'center'
	});
	var label = Titanium.UI.createLabel({
		text: caption,
		textAlign: 'center'
	});
	view.add(label);
    var thumbnailImageUrl = 
        baseUrl + '/Listing/Thumbnail?ListingId=' + 
        listingId + '&ImageKey=' + imageKey; 
    Titanium.API.info("window_detail: create thumbnail with url: " +
        thumbnailImageUrl);
    var thumbnail = Titanium.UI.createImageView({
        url: thumbnailImageUrl,
        width: 80, height: 80, top:0, left:0
    });
    var largeImageUrl =
        baseUrl + '/Listing/Image?ListingId=' +
        listingId + '&ImageKey=' + imageKey;
    thumbnail.addEventListener('click', function() {
        showLargeImage(largeImageUrl);
    });
    view.add(thumbnail);
	return view;
}
var scrollView = Titanium.UI.createScrollView({
	contentHeight: 'auto',
	contentWidth: 'auto',
	top : 38,
	left: 20,
	height: 85,
	width: 280,
	borderWidth:1,
	showHorizontalScrollIndicator:true
});

var getThumbnailsUrl = baseUrl + '/Listing/ImageKeys?ListingId=' + win.listing.Id;
var _xhrGetThumbnails = Titanium.Network.createHTTPClient();
_xhrGetThumbnails.onload = function()
{
    Titanium.API.info('window_detail (thumbnail load) ' + _xhrGetThumbnails.responseText);
    
    var imageKeys = JSON.parse(_xhrGetThumbnails.responseText);
    if (imageKeys && imageKeys.length > 0)
    {
        Titanium.API.info('window_detail get thumbnails succeeded: ' + imageKeys.length + ' found');
        for(i=0;i<imageKeys.length;i++)
        {
            scrollView.add(getThumbnailView('', win.listing.Id, imageKeys[i]));
        }
    }
    else
    {
        Titanium.API.info('get thumbnails failed');
    }
};
_xhrGetThumbnails.onerror = function()
{
	Titanium.API.info("app - listing info load failed.");
    var a = Titanium.UI.createAlertDialog({
        title:'Network Error',
        message:'Could not retrieve thumbnail images'
    });
    a.show();
};
Titanium.API.info('Requesting: ' + getThumbnailsUrl);
_xhrGetThumbnails.open('GET', getThumbnailsUrl);
_xhrGetThumbnails.send();

win.add(scrollView);

var phoneNumberBox = Titanium.UI.createView({
	top: 231,
	height: 35,
	width: 300,
	left: 10,
	borderRadius: 10,
	borderColor: borderColor,
	backgroundColor: boxBackground
});
var phoneLabel = Titanium.UI.createLabel({
	text: 'Call',
	left: 20,
	color: lightText,
	font: bigFont
});
var phoneText = Titanium.UI.createLabel({
	text: win.listing.ContactPhone,
	color: blueText,
	font: bigFont,
	left: 100
});
phoneNumberBox.add(phoneLabel);
phoneNumberBox.add(phoneText);
win.add(phoneNumberBox);

var emailBox = Titanium.UI.createView({
	top: 273,
	height: 35,
	width: 300,
	left: 10,
	borderRadius: 10,
	borderColor: borderColor,
	backgroundColor: boxBackground
});
var emailLabel = Titanium.UI.createLabel({
	text: 'E-mail',
	color: lightText,
	left: 20,
	font: bigFont
});
var emailText = Titanium.UI.createLabel({
	text: win.listing.ContactEMail,
	color: blueText,
	font: bigFont,
	left: 100
});
emailBox.add(emailLabel);
emailBox.add(emailText);
win.add(emailBox);

var addressBox = Titanium.UI.createView({
	top: 315,
	height: 45,
	width: 300,
	left: 10,
	borderRadius: 10,
	borderThickness: 1,
	borderColor: borderColor,
	backgroundColor: boxBackground
});
var addressLabel = Titanium.UI.createLabel({
	text: 'Address',
	color: lightText,
	font: bigFont,
	left: 20
});
var addressText = Titanium.UI.createLabel({
	text: win.listing.FullAddress,
	color: blueText,
	font: bigFont,
	left: 100,
	right: 15
});
addressBox.add(addressLabel);
addressBox.add(addressText);
win.add(addressBox);

