//
// Window_Map.js
//
// initialize UI for map window
//
var win = Titanium.UI.currentWindow;
var _mapview = null;
var _mapActInd = null;
var _defaultDelta = 0.05;
var _lastActionTitle = null;
var baseUrl;
if (win)
{
    baseUrl = win.baseUrl;
    Titanium.API.info("window_map - baseUrl = " + baseUrl);
}
else
{
    Titanium.API.info("window_map - baseUrl not set: window is empty");
}

var _showDetailInterlock = false;
function showListingDetail(listingToShow)
{
    if (listingToShow)
    {
        Titanium.API.info('window_map - create detail window');
        var detailWindow = Titanium.UI.createWindow({
            listing: listingToShow,
            url: 'window_detail.js',
            baseUrl: baseUrl
        });
        Titanium.API.info('window_map - open detail window');
        Titanium.UI.currentTab.open(detailWindow,{animated:true});
    }
    else
    {
        Titanium.API.info('window_map - showListingDetail is missing listing');
    }
}

function mapClick(e)
{
	if (!e)
	{
		Titanium.API.info('window_map mapClick - argument empty');
	}
	
    Titanium.API.info("window_map mapClick - " + e.clicksource);
    if (e.clicksource == 'title' || e.clicksource == 'subtitle')
    {
        if (_showDetailInterlock)
        {
            Titanium.API.info('window_map - discarding extra click event');
        }
        else
        {
            _showDetailInterlock = true;
            showListingDetail(e.annotation.listing); 
            setTimeout(function() { _showDetailInterlock = false; }, 500);
        }
    }
};
    
Titanium.App.addEventListener('location_changed', function(e) 
{
	Titanium.API.info('mapview.location_changed start');
    _lastActionTitle = e.title;
	var loc = {
		latitude: e.latitude,
		longitude: e.longitude,
		latitudeDelta: _defaultDelta,
		longitudeDelta: _defaultDelta
	};
	if (null == _mapview)
	{
		Titanium.API.log('no mapview --------------------');
	    Titanium.API.info('mapview.location_changed creating MapView');
	    _mapview = Titanium.Map.createView(
	    {
	        mapType: Titanium.Map.STANDARD_TYPE,
	        region: loc,
	        animate:true,
	        regionFit:true,
	        userLocation:true,
            zIndex: 0
	    });
    
	    _mapview.addEventListener('regionChanged',function(evt)
	    {
	        var rect = {
	            N: evt.latitude + evt.latitudeDelta/2,
	            S: evt.latitude - evt.latitudeDelta/2,
	            E: evt.longitude + evt.longitudeDelta/2,
	            W: evt.longitude - evt.longitudeDelta/2
	        };

	        Titanium.API.info('window_map.location_changed: Map region changed to ' + JSON.stringify(rect) + ' - firing mapregion_changed');
			win.busy.show();
			Titanium.App.fireEvent('mapregion_changed', rect);
	    });
        
	    _mapview.addEventListener('click', mapClick);


	    win.add(_mapview);
	}
	else
	{
		Titanium.API.info('mapview.location_changed setting new location');
	    _mapview.setLocation(loc);
		_mapview.addEventListener('click', mapClick);
	}
	win.Title = e.title;
});

win.busy = Titanium.UI.createActivityIndicator({
    style:Titanium.UI.iPhone.ActivityIndicatorStyle.BIG,
    zIndex: 10
});
win.setRightNavButton(win.busy);

win.blockingBusy = Titanium.UI.createActivityIndicator({
    font: {fontFamily:'Helvetica Neue', fontSize:15,fontWeight:'bold'},
    message: 'Please wait...',
    style:Titanium.UI.iPhone.ActivityIndicatorStyle.BIG,
    zIndex: 10
});
win.add(win.blockingBusy);
win.blockingBusy.show();

var _annotations = [];
function update()
{
	var listings = win.listings;

	if (null != listings)
	{
		oldAnnotations = _annotations;
	    Titanium.API.info('removing ' + oldAnnotations.length + ' annotations');
	    _mapview.removeAnnotations(oldAnnotations);
	    _annotations = [];

	    for(i=0;i<listings.length;i++)
	    {
	        var listing = listings[i];
	        // Titanium.API.info('creating map pin at ' + listing.Latitude + ',' + listing.Longitude);

	        var annotation = Titanium.Map.createAnnotation({
	            latitude: listing.Latitude,
	            longitude: listing.Longitude,
	            title: listing.Title,
				subtitle: 
					listing.BuildingType + ' - ' + 
					listing.SquareFeet + 'SF ' +
					(listing.PricePerSqFt <= 0 ? 'n/a' : '$' + listing.PricePerSqFt),
				animate: false,
	            listing: listing
	            });

			var popupView = Titanium.UI.createView({
				width: 60,
				height: 60,
				backgroundColor: 'transparent'
			});
			popupView.add(Titanium.UI.createImageView({
				url: 
					'http://www.comient.com/Listing/AnyThumbnail?ListingId=' +
					listing.Id,
				top: 0, left: 0, width:60, height: 60
				}));

	        _annotations[_annotations.length] = annotation;
	    }
	    Titanium.API.info('adding ' + _annotations.length + ' annotations');
	    _mapview.addAnnotations(_annotations);

		var count = listings ? listings.length : 0;
		var newTitle = count.toString() + 
			' Listing' + 
			(count != 1 ? 's' : '');
		if (_lastActionTitle)
		{
		   newTitle = _lastActionTitle + ' - ' + newTitle;
		}
		win.title = newTitle;

		// The last action title should only be used once.
		// If it is not triggered by the external action we
		// need to forget it.
		_lastActionTitle = null;
	}
	win.blockingBusy.hide();
	win.busy.hide();
}

Titanium.App.addEventListener('listings_updated', function() { update(); });

if (win.listings)
{
	update();
}

